=============
Release notes
=============

The release notes for a patch should be included in the
patch. The intended audience for release notes include
deployers, administrators and end-users.

A release note is required if the patch has upgrade or API
impact. It is also required if the patch adds a feature or
fixes a long-standing or security bug.

Please see
https://docs.openstack.org/cinder/latest/contributor/releasenotes.html
for more details.

